"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createPageBlocksUpdateValidation = exports.createPageBlocksCreateValidation = void 0;
var _zod = _interopRequireDefault(require("zod"));
const refineValidation = value => {
  if (!value) {
    return false;
  } else if (value.match(/^[a-z0-9]+(-[a-z0-9]+)*$/) === null) {
    return false;
  }
  return true;
};
const refineValidationMessage = value => {
  if (!value) {
    return {
      message: "Value is required."
    };
  }
  return {
    message: "Slug must consist of only 'a-z', '0-9' and '-' and be max 100 characters long (for example: 'some-slug' or 'some-slug-2')"
  };
};
const baseValidation = _zod.default.object({
  name: _zod.default.string().min(1).max(100),
  content: _zod.default.union([_zod.default.object({}).passthrough(), _zod.default.array(_zod.default.object({}).passthrough())])
});
const createPageBlocksCreateValidation = () => {
  return baseValidation.extend({
    blockCategory: _zod.default.string().min(1).max(100).refine(refineValidation, refineValidationMessage)
  });
};
exports.createPageBlocksCreateValidation = createPageBlocksCreateValidation;
const createPageBlocksUpdateValidation = () => {
  return baseValidation.extend({
    blockCategory: _zod.default.string().max(100).optional().transform(value => {
      return value || undefined;
    }).refine(value => {
      if (!value) {
        return true;
      }
      return refineValidation(value);
    }, refineValidationMessage)
  }).partial();
};
exports.createPageBlocksUpdateValidation = createPageBlocksUpdateValidation;

//# sourceMappingURL=validation.js.map